#
# spec file for package python-aiostream
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global modname aiostream
%{?sle15_python_module_pythons}
Name:           python-aiostream
Version:        0.6.4
Release:        1.3
Summary:        Generator-based operators for asynchronous iteration
License:        Apache-2.0
URL:            https://github.com/vxgmichel/%{modname}
Source:         https://github.com/vxgmichel/%{modname}/archive/refs/tags/v%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-siosocks >= 0.2.0
Requires:       python-typing-extensions
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module typing-extensions}
# /SECTION
%python_subpackages

%description
aiostream provides a collection of stream operators that can be
combined to create asynchronous pipelines of operations.

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/%{modname}-%{version}*-info
%{python_sitelib}/%{modname}

%changelog
* Fri Nov  8 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.6.4
  * Drop support for python 3.8, add support
    for python 3.13 by @fpgmaas in (#123)
- from version 0.6.3
  * Add MANIFEST.in to include tests/conftests.py in
    source dist by @vxgmichel (issue #121, PR #122)
- from version 0.6.2
  * Fixing the issue of the lack of installation sections
    by @thepapermen in (#113)
  * Configure pytest test paths so test_utils.py is not
    mistaken for a test file by @vxgmichel in (#117)
  * Add strict parameter to stream.zip by @smheidrich in (#119)
- from version 0.6.1
  * Fix documentation build (42f9119)
  * Expose Stream and sources_operator
    in the aiostream package (e029efd)
- from version 0.6.0
  * Support python 3.12 (PR #93)
  * Support pyright and improve typing in general (PR #99)
  * Move from setup.* to pyproject.toml (PR #101, #102, #103, #110)
  * Add typing to aiostream.test_utils (PR #104)
  * Make operators a singleton object instead of a class (PR #106)
  * Add sources operator to fix a breaking change in v0.5.x (PR #108, issue #95)
- Add python-pytest-cov to BuildRequires
- Drop sed command to remove coverage parameters from setup.cfg
* Thu Dec 14 2023 Petr Gajdos <pgajdos@suse.com>
- update to 0.5.2:
  * Properly expose pipe methods in `aiostream.pipe` (PR #88,
    issue #87)
- update to 0.5.1:
  * Expose `pipable_operator` at package level (46ddb24)
  * Modernize examples (a704e9a)
- update to 0.5.0:
  * Drop python 3.7 support
  * Add type annotations (issue #36, PR #84)
  * Add task_limit argument to action operator (issue #85, PR
    [#86])
* Tue Dec 20 2022 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for aiostream 0.4.5.
